==========
Algorithms
==========

:mod:`aif360.algorithms.preprocessing`
======================================

.. automodule:: aif360.algorithms.preprocessing
    :no-members:
    :no-inherited-members:

.. currentmodule:: aif360

.. autosummary::
   :toctree: generated/
   :template: class.rst

   algorithms.preprocessing.DisparateImpactRemover
   algorithms.preprocessing.LFR
   algorithms.preprocessing.OptimPreproc
   algorithms.preprocessing.Reweighing

:mod:`aif360.algorithms.inprocessing`
=====================================

.. automodule:: aif360.algorithms.inprocessing
    :no-members:
    :no-inherited-members:

.. currentmodule:: aif360

.. autosummary::
   :toctree: generated/
   :template: class.rst

   algorithms.inprocessing.AdversarialDebiasing
   algorithms.inprocessing.ARTClassifier
   algorithms.inprocessing.GerryFairClassifier
   algorithms.inprocessing.MetaFairClassifier
   algorithms.inprocessing.PrejudiceRemover
   algorithms.inprocessing.ExponentiatedGradientReduction
   algorithms.inprocessing.GridSearchReduction

:mod:`aif360.algorithms.postprocessing`
=======================================

.. automodule:: aif360.algorithms.postprocessing
    :no-members:
    :no-inherited-members:

.. currentmodule:: aif360

.. autosummary::
   :toctree: generated/
   :template: class.rst

   algorithms.postprocessing.CalibratedEqOddsPostprocessing
   algorithms.postprocessing.EqOddsPostprocessing
   algorithms.postprocessing.RejectOptionClassification
   algorithms.postprocessing.DeterministicReranking

:mod:`aif360.algorithms`
========================

.. automodule:: aif360.algorithms
   :no-members:
   :no-inherited-members:

.. currentmodule:: aif360

.. autosummary::
   :toctree: generated/
   :template: class.rst

   algorithms.Transformer
